from setuptools import setup

setup(name='udacity_distr',
      version='0.5',
      description='Gaussian and Binomial distributions',
      packages=['udacity_distr'],
      author='saber_bounehas',
      author_email='samirsamado5@gmail.com',
      zip_safe=False)
